History  
=======

0.1.3 (2020-01-20)  
------------------

Features  
~~~~~~~~
* `#2 <https://github.com/aklajnert/changelogd/pull/2>`_: Allow to control which user data will be saved in entries.
* `#3 <https://github.com/aklajnert/changelogd/pull/3>`_: Automatically add new entries and releases to git.

Other changes  
~~~~~~~~~~~~~
* `#1 <https://github.com/aklajnert/changelogd/pull/1>`_: Switch from ``tox`` to ``nox`` for running tests and tasks.

0.1.2 (2020-01-17)  
------------------

Bug fixes  
~~~~~~~~~
* Fixed missing templates from the ``MANIFEST.in``

0.1.1 (2020-01-16)  
------------------

Initial release  
